@@ -10,13 +10,40 @@ import json
 import logging
 import os
 import re
-import urllib.request
+import shutil
 from collections import namedtuple
 from configparser import ConfigParser
+from pathlib import Path
+from urllib.error import URLError
+from urllib.request import urlopen
 
 LOG = logging.getLogger(__name__)
 
 
+def create_skel_dir():
+    """Install data_files in the /etc directory."""
+    base_env = Path(os.environ.get('VIRTUAL_ENV', '/'))
+    etc_kytos = base_env / 'etc' / 'kytos'
+
+    # kytos-utils/kytos/utils/config.py -> kytos-utils/kytos
+    parent_dir = Path(__file__).resolve().parent.parent
+
+    if not etc_kytos.exists():
+        os.makedirs(etc_kytos)
+
+    src = parent_dir / 'templates' / 'skel'
+    dst = etc_kytos / 'skel'
+
+    if dst.exists():
+        if not next(dst.iterdir(), None):
+            # Path already exists but it's empty, so we'll populate it
+            # We remove it first to avoid an exception from copytree
+            dst.rmdir()
+            shutil.copytree(str(src), str(dst))
+    else:
+        shutil.copytree(str(src), str(dst))
+
+
 class KytosConfig():
     """Kytos Configs.
 
@@ -29,6 +56,7 @@ class KytosConfig():
 
         Receive the config_file as argument.
         """
+        create_skel_dir()
         self.config_file = os.path.expanduser(config_file)
         self.debug = False
         if self.debug:
@@ -140,19 +168,23 @@ class KytosConfig():
         """Return kytos metadata."""
         kytos_api = KytosConfig().config.get('kytos', 'api')
         meta_uri = kytos_api + 'api/kytos/core/metadata/'
-        meta_file = urllib.request.urlopen(meta_uri).read()
+        meta_file = urlopen(meta_uri).read()
         metadata = json.loads(meta_file)
         return metadata
 
     @classmethod
     def check_versions(cls):
         """Check if kytos and kytos-utils metadata are compatible."""
-        kytos_metadata = cls.get_remote_metadata()
-        kutils_metadata = cls.get_metadata()
-        kytos_version = kytos_metadata.get('__version__')
-        kutils_version = kutils_metadata.get('__version__')
+        try:
+            kytos_metadata = cls.get_remote_metadata()
+            kytos_version = kytos_metadata.get('__version__')
+        except URLError as exc:
+            LOG.debug('Couldn\'t connect to kytos server: %s', exc)
+        else:
+            kutils_metadata = cls.get_metadata()
+            kutils_version = kutils_metadata.get('__version__')
 
-        if kytos_version != kutils_version:
-            logger = logging.getLogger()
-            logger.warning('kytos (%s) and kytos utils (%s) versions '
-                           'are not equal.', kytos_version, kutils_version)
+            if kytos_version != kutils_version:
+                logger = logging.getLogger()
+                logger.warning('kytos (%s) and kytos utils (%s) versions '
+                               'are not equal.', kytos_version, kutils_version)
