@@ -129,7 +129,7 @@ class NAppsManager:
             content = json.loads(response.read())
             return sorted((c[0], c[1]) for c in content['napps'])
         except urllib.error.URLError as exception:
-            LOG.error("Error checking installed NApps. Is Kytos running?")
+            LOG.error("Error checking enabled NApps. Is Kytos running?")
             raise KytosException(exception)
 
     def get_installed(self):
@@ -302,15 +302,10 @@ class NAppsManager:
         uri = self._kytos_api + self._NAPP_INSTALL
         uri = uri.format(self.user, self.napp)
 
-        try:
-            json.loads(urllib.request.urlopen(uri).read())
-        except urllib.error.HTTPError as exception:
-            if exception.code == HTTPStatus.BAD_REQUEST.value:
-                LOG.error("NApp is not installed. Check the NApp list.")
-            else:
-                LOG.error("Error installing the NApp.")
+        json.loads(urllib.request.urlopen(uri).read())
 
     @classmethod
+    # pylint: disable=too-many-statements
     def create_napp(cls, meta_package=False):
         """Bootstrap a basic NApp structure for you to develop your NApp.
 
@@ -323,25 +318,28 @@ class NAppsManager:
 
         username = None
         napp_name = None
-
         print('--------------------------------------------------------------')
         print('Welcome to the bootstrap process of your NApp.')
         print('--------------------------------------------------------------')
-        print('In order to answer both the username and the napp name,')
-        print('You must follow this naming rules:')
+        print('In order to answer both the username and the NApp name,')
+        print('You must follow these naming rules:')
         print(' - name starts with a letter')
         print(' - name contains only letters, numbers or underscores')
         print(' - at least three characters')
         print('--------------------------------------------------------------')
         print('')
-        while not cls.valid_name(username):
-            username = input('Please, insert your NApps Server username: ')
+        try:
+            while not cls.valid_name(username):
+                username = input('Please, insert your NApps Server username: ')
 
-        while not cls.valid_name(napp_name):
-            napp_name = input('Please, insert your NApp name: ')
+            while not cls.valid_name(napp_name):
+                napp_name = input('Please, insert your NApp name: ')
 
-        description = input('Please, insert a brief description for your'
-                            'NApp [optional]: ')
+            description = input('Please, insert a brief description for your '
+                                'NApp [optional]: ')
+        except KeyboardInterrupt:
+            print("User cancelled NApp creation.")
+            sys.exit(0)
         if not description:
             # pylint: disable=fixme
             description = '# TODO: <<<< Insert your NApp description here >>>>'
@@ -355,7 +353,7 @@ class NAppsManager:
 
         #: Creating ``__init__.py`` files
         with open(os.path.join(username, '__init__.py'), 'w') as init_file:
-            init_file.write(f'"""Napps for the user {username}.""""')
+            init_file.write(f'"""NApps for the user {username}.""""')
 
         os.makedirs(os.path.join(username, napp_name))
 
@@ -379,10 +377,9 @@ class NAppsManager:
             NAppsManager.create_ui_structure(username, napp_name,
                                              ui_templates_path, context)
 
-        print()
-        print(f'Congratulations! Your NApp has been bootstrapped!\nNow you '
-              'can go to the directory {username}/{napp_name} and begin to '
-              'code your NApp.')
+        print('\nCongratulations! Your NApp has been bootstrapped!\nNow you'
+              f' can go to the directory "{username}/{napp_name}" and begin'
+              ' to code your NApp.')
         print('Have fun!')
 
     @classmethod
@@ -431,8 +428,14 @@ class NAppsManager:
         def get_matches(path):
             """Return all NApp files matching any .gitignore pattern."""
             ignored_files = [".git"]
-            with open(".gitignore", 'r') as kytosignore:
-                ignored_files.extend(kytosignore.readlines())
+            with open(".gitignore", 'r') as local_gitignore:
+                ignored_files.extend(local_gitignore.readlines())
+
+            user_gitignore_path = pathlib.Path("%s/.gitignore" %
+                                               pathlib.Path.home())
+            if user_gitignore_path.exists():
+                with open(user_gitignore_path, 'r') as user_gitignore:
+                    ignored_files.extend(user_gitignore.readlines())
 
             # Define Wildmatch pattern (default gitignore pattern)
             pattern = pathspec.patterns.GitWildMatchPattern
